@@ -25,12 +25,20 @@
 # established at this point, and setup.py will use a version of next-$(revno).
 # If the releaselevel is 'final', then the tarball will be major.minor.micro.
 # Otherwise it is major.minor.micro~$(revno).
-__version__ = (0, 0, 10, 'beta', 0)
+__version__ = (0, 0, 11, 'final', 0)
 
 __all__ = [
     'Config',
+    'convert_result_to_list',
     'publish_new_only',
+    'publish_to_many',
+    'publish_with_fallback',
     ]
 
 from oops.config import Config
-from oops.publishers import publish_new_only
+from oops.publishers import (
+    convert_result_to_list,
+    publish_new_only,
+    publish_to_many,
+    publish_with_fallback,
+    )
